Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(208)

Unified Diff: runtime/include/dart_api.h

Issue 10831165: Made it possible to distinguish between a method or top-level function and the (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_api.h
===================================================================
--- runtime/include/dart_api.h (revision 10248)
+++ runtime/include/dart_api.h (working copy)
@@ -2071,17 +2071,16 @@
DART_EXPORT Dart_Handle Dart_FunctionName(Dart_Handle function);
/**
* Returns a handle to the enclosing class or library for a function. If this
* function is an instance method, a static method or the function of a closure
* defined in such, it has an enclosing class. If this function is a top-level
* function or the function of a closure defined in such, it has an enclosing
* library.
*
* \return A valid handle on the enclosing class or library of the function, or
* an error handle if the argument is not a valid handle to a function.
*/
-DART_EXPORT Dart_Handle Dart_FunctionEnclosingClassOrLibrary(
- Dart_Handle function);
+DART_EXPORT Dart_Handle Dart_FunctionOwner(Dart_Handle function);
/**
* Determines whether a function handle refers to an abstract method.
« no previous file with comments | « no previous file | runtime/vm/dart_api_impl.cc » ('j') | no next file with comments »
@@ -2071,17 +2071,16 @@
DART_EXPORT Dart_Handle Dart_FunctionName(Dart_Handle function);
/**
- * Returns a handle to the enclosing class or library for a function. If this
- * function is an instance method, a static method or the function of a closure
- * defined in such, it has an enclosing class. If this function is a top-level
- * function or the function of a closure defined in such, it has an enclosing
- * library.
+ * Returns a handle to the owner of a function. The owner of an instance method
+ * or a static method is its defining class. The owner of a top-level function
+ * is its defining library. The owner of the function of a non-implicit closure
+ * is the function of the method or closure that defines the non-implicit
+ * closure.
*
@@ -2071,17 +2071,16 @@
*
- * \return A valid handle on the enclosing class or library of the function, or
- * an error handle if the argument is not a valid handle to a function.
+ * \return A valid handle on the owner of the function, or an error handle if
+ * the argument is not a valid handle to a function.
*/

Powered by Google App Engine
This is Rietveld 408576698